@@ -30,6 +30,8 @@
 #include "compat.h"
 #include "settings.h"
 #include "bookmark.h"
+#include "backendgvfs.h"
+#include "window.h"
 #include "bookmarkeditdialog.h"
 
 
@@ -40,7 +42,7 @@ typedef struct _GigoloBookmarkEditDialogPrivate			GigoloBookmarkEditDialogPrivat
 
 struct _GigoloBookmarkEditDialogPrivate
 {
-	GigoloSettings *settings;
+	GigoloWindow *parent;
 
 	GtkWidget *table;
 
@@ -56,8 +58,8 @@ struct _GigoloBookmarkEditDialogPrivate
 	GtkWidget *uri_label;
 	GtkWidget *uri_entry;
 
-	GtkWidget *server_label;
-	GtkWidget *server_entry;
+	GtkWidget *host_label;
+	GtkWidget *host_entry;
 
 	GtkWidget *port_label;
 	GtkWidget *port_spin;
@@ -69,6 +71,8 @@ struct _GigoloBookmarkEditDialogPrivate
 	GtkWidget *domain_entry;
 
 	GtkWidget *share_label;
+	GtkWidget *share_combo;
+	GtkWidget *share_button;
 	GtkWidget *share_entry;
 
 	GigoloBookmark *bookmark_init;
@@ -98,7 +102,8 @@ enum {
 	SHOW_SHARE     = 0x00000010,
 	SHOW_PORT      = 0x00000020,
 	SHOW_USER      = 0x00000040,
-	SHOW_DOMAIN    = 0x00000080
+	SHOW_DOMAIN    = 0x00000080,
+	SHOW_DEVICE    = 0x00000100
 };
 
 enum {
@@ -114,6 +119,7 @@ enum {
 	SCHEME_SMB,
 	SCHEME_DAV,
 	SCHEME_DAVS,
+	SCHEME_OBEX,
 	SCHEME_CUSTOM
 };
 
@@ -123,6 +129,7 @@ static struct MethodInfo methods[] = {
 	{ "smb",  0,	SHOW_SHARE | SHOW_USER | SHOW_DOMAIN },
 	{ "dav",  80,	SHOW_PORT | SHOW_USER },
 	{ "davs", 443,	SHOW_PORT | SHOW_USER },
+	{ "obex", 0,	SHOW_DEVICE },
 	{ NULL,   0,	0 }
 };
 static guint methods_len = G_N_ELEMENTS(methods);
@@ -139,15 +146,16 @@ static void gigolo_bookmark_edit_dialog_destroy(GtkObject *object)
 
 	gtk_widget_destroy(priv->uri_entry);
 	gtk_widget_destroy(priv->uri_label);
-	gtk_widget_destroy(priv->server_entry);
-	gtk_widget_destroy(priv->server_label);
+	gtk_widget_destroy(priv->host_entry);
+	gtk_widget_destroy(priv->host_label);
 	gtk_widget_destroy(priv->port_label);
 	gtk_widget_destroy(priv->port_spin);
 	gtk_widget_destroy(priv->user_entry);
 	gtk_widget_destroy(priv->user_label);
 	gtk_widget_destroy(priv->domain_entry);
 	gtk_widget_destroy(priv->domain_label);
-	gtk_widget_destroy(priv->share_entry);
+	gtk_widget_destroy(priv->share_combo);
+	gtk_widget_destroy(priv->share_button);
 	gtk_widget_destroy(priv->share_label);
 	gtk_widget_destroy(priv->information_label);
 
@@ -184,7 +192,8 @@ gint gigolo_bookmark_edit_dialog_run(GigoloBookmarkEditDialog *dialog)
 				}
 				else
 				{	/* check for duplicate bookmark names */
-					GigoloBookmarkList *bml = gigolo_settings_get_bookmarks(priv->settings);
+					GigoloSettings *settings = gigolo_window_get_settings(GIGOLO_WINDOW(priv->parent));
+					GigoloBookmarkList *bml = gigolo_settings_get_bookmarks(settings);
 					GigoloBookmark *bm;
 					guint i;
 
@@ -203,18 +212,18 @@ gint gigolo_bookmark_edit_dialog_run(GigoloBookmarkEditDialog *dialog)
 					}
 				}
 			}
-			if (! error && gtk_widget_get_parent(priv->server_entry) != NULL)
+			if (! error && gtk_widget_get_parent(priv->host_entry) != NULL)
 			{
-				tmp = gtk_entry_get_text(GTK_ENTRY(priv->server_entry));
+				tmp = gtk_entry_get_text(GTK_ENTRY(priv->host_entry));
 				if (! *tmp)
 				{
 					error = TRUE;
 					gigolo_message_dialog((gpointer)dialog, GTK_MESSAGE_ERROR, _("Error"),
 						_("You must enter a server address or name."), NULL);
-					gtk_widget_grab_focus(priv->server_entry);
+					gtk_widget_grab_focus(priv->host_entry);
 				}
 			}
-			if (! error && gtk_widget_get_parent(priv->share_entry) != NULL)
+			if (! error && gtk_widget_get_parent(priv->share_combo) != NULL)
 			{
 				tmp = gtk_entry_get_text(GTK_ENTRY(priv->share_entry));
 				if (! *tmp)
@@ -222,7 +231,7 @@ gint gigolo_bookmark_edit_dialog_run(GigoloBookmarkEditDialog *dialog)
 					error = TRUE;
 					gigolo_message_dialog((gpointer)dialog, GTK_MESSAGE_ERROR, _("Error"),
 						_("You must enter a share name."), NULL);
-					gtk_widget_grab_focus(priv->share_entry);
+					gtk_widget_grab_focus(priv->share_combo);
 				}
 			}
 			if (! error && gtk_widget_get_parent(priv->uri_entry) != NULL)
@@ -302,8 +311,8 @@ static guint scheme_to_index(const gchar *scheme)
 static gboolean combo_foreach(GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path,
 							  GtkTreeIter *iter, gpointer data)
 {
-	gint idx = GPOINTER_TO_INT(data);
-	gint i;
+	guint idx = GPOINTER_TO_UINT(data);
+	guint i;
 
 	gtk_tree_model_get(model, iter, COLUMN_INDEX, &i, -1);
 
@@ -318,21 +327,25 @@ static gboolean combo_foreach(GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *pa
 }
 
 
-static void combo_set_active(GtkWidget *combo, gint idx)
+static void combo_set_active(GtkWidget *combo, guint idx)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
 	gboolean visible = FALSE;
 	gboolean is_valid;
 
-	gtk_tree_model_foreach(model, combo_foreach, GINT_TO_POINTER(idx));
+	/* Don't do anything if the initial scheme has been set already. */
+	if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter))
+		return;
+
+	gtk_tree_model_foreach(model, combo_foreach, GUINT_TO_POINTER(idx));
 
 	/* Prevent setting an invisible/unsupported scheme, fallback to Custom Location. */
 	is_valid = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter);
 	if (is_valid)
 		gtk_tree_model_get(model, &iter, COLUMN_VISIBLE, &visible, -1);
-	if (! visible || !is_valid)
-		gtk_tree_model_foreach(model, combo_foreach, GINT_TO_POINTER(SCHEME_CUSTOM));
+	if (! visible || ! is_valid)
+		gtk_tree_model_foreach(model, combo_foreach, GUINT_TO_POINTER(SCHEME_CUSTOM));
 }
 
 
@@ -344,41 +357,64 @@ static void init_values(GigoloBookmarkEditDialog *dialog)
 	guint port;
 	guint idx;
 
+	/* Name */
 	tmp = gigolo_bookmark_get_name(priv->bookmark_init);
 	if (tmp != NULL)
 		gtk_entry_set_text(GTK_ENTRY(priv->name_entry), tmp);
+	/* URI */
 	uri = gigolo_bookmark_get_uri(priv->bookmark_init);
 	if (uri != NULL)
 	{
 		gtk_entry_set_text(GTK_ENTRY(priv->uri_entry), uri);
 		g_free(uri);
 	}
+	/* Host */
 	tmp = gigolo_bookmark_get_host(priv->bookmark_init);
 	if (tmp != NULL)
-		gtk_entry_set_text(GTK_ENTRY(priv->server_entry), tmp);
+	{
+		gchar *host;
+		if (tmp[0] == '[' && gigolo_str_equal("obex", gigolo_bookmark_get_scheme(priv->bookmark_init)))
+		{
+			gsize len = strlen(tmp);
+			/* tmp is something like [00:00:00:00:00] and we want to strip the brackets */
+			host = g_strndup(tmp + 1, len - 2);
+		}
+		else
+			host = (gchar *) tmp;
+
+		gtk_entry_set_text(GTK_ENTRY(priv->host_entry), host);
+		if (tmp != host)
+			g_free(host);
+	}
+	/* Host */
 	user = gigolo_bookmark_get_user_unescaped(priv->bookmark_init);
 	if (user != NULL)
 	{
 		gtk_entry_set_text(GTK_ENTRY(priv->user_entry), user);
 		g_free(user);
 	}
+	/* Share */
 	tmp = gigolo_bookmark_get_share(priv->bookmark_init);
 	if (tmp != NULL)
 		gtk_entry_set_text(GTK_ENTRY(priv->share_entry), tmp);
+	/* Domain */
 	tmp = gigolo_bookmark_get_domain(priv->bookmark_init);
 	if (tmp != NULL)
 		gtk_entry_set_text(GTK_ENTRY(priv->domain_entry), tmp);
+	/* Port */
 	port = gigolo_bookmark_get_port(priv->bookmark_init);
+
 	idx = scheme_to_index(gigolo_bookmark_get_scheme(priv->bookmark_init));
-	if (port == 0)
-		port = methods[idx].port;
 
 	gtk_toggle_button_set_active(
 		GTK_TOGGLE_BUTTON(priv->autoconnect_checkbtn),
 		gigolo_bookmark_get_autoconnect(priv->bookmark_init));
 
+	if (port == 0)
+		port = methods[idx].port;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->port_spin), port);
-	combo_set_active(priv->type_combo, (gint) idx);
+
+	combo_set_active(priv->type_combo, idx);
 }
 
 
@@ -404,10 +440,10 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 		gtk_container_remove(GTK_CONTAINER(priv->table), priv->uri_label);
 		gtk_container_remove(GTK_CONTAINER(priv->table), priv->uri_entry);
 	}
-	if (gtk_widget_get_parent(priv->server_entry) != NULL)
+	if (gtk_widget_get_parent(priv->host_entry) != NULL)
 	{
-		gtk_container_remove(GTK_CONTAINER(priv->table), priv->server_label);
-		gtk_container_remove(GTK_CONTAINER(priv->table), priv->server_entry);
+		gtk_container_remove(GTK_CONTAINER(priv->table), priv->host_label);
+		gtk_container_remove(GTK_CONTAINER(priv->table), priv->host_entry);
 	}
 	if (gtk_widget_get_parent(priv->port_spin) != NULL)
 	{
@@ -424,10 +460,11 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 		gtk_container_remove(GTK_CONTAINER(priv->table), priv->domain_label);
 		gtk_container_remove(GTK_CONTAINER(priv->table), priv->domain_entry);
 	}
-	if (gtk_widget_get_parent(priv->share_entry) != NULL)
+	if (gtk_widget_get_parent(priv->share_combo) != NULL)
 	{
 		gtk_container_remove(GTK_CONTAINER(priv->table), priv->share_label);
-		gtk_container_remove(GTK_CONTAINER(priv->table), priv->share_entry);
+		gtk_container_remove(GTK_CONTAINER(priv->table), priv->share_combo);
+		gtk_container_remove(GTK_CONTAINER(priv->table), priv->share_button);
 	}
 	if (gtk_widget_get_parent(priv->information_label) != NULL)
 	{
@@ -453,14 +490,19 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 	}
 	else
 	{
-		gtk_misc_set_alignment(GTK_MISC(priv->server_label), 0.0, 0.5);
-		gtk_widget_show(priv->server_label);
-		gtk_table_attach(GTK_TABLE(table), priv->server_label,
+		if (meth->flags & SHOW_DEVICE)
+			gtk_label_set_text_with_mnemonic(GTK_LABEL(priv->host_label), _("_Device:"));
+		else
+			gtk_label_set_text_with_mnemonic(GTK_LABEL(priv->host_label), _("_Server:"));
+
+		gtk_misc_set_alignment(GTK_MISC(priv->host_label), 0.0, 0.5);
+		gtk_widget_show(priv->host_label);
+		gtk_table_attach(GTK_TABLE(table), priv->host_label,
 				  0, 1, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
 
-		gtk_label_set_mnemonic_widget(GTK_LABEL(priv->server_label), priv->server_entry);
-		gtk_widget_show(priv->server_entry);
-		gtk_table_attach(GTK_TABLE(table), priv->server_entry,
+		gtk_label_set_mnemonic_widget(GTK_LABEL(priv->host_label), priv->host_entry);
+		gtk_widget_show(priv->host_entry);
+		gtk_table_attach(GTK_TABLE(table), priv->host_entry,
 				  1, 2, i, i+1, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
 
 		i++;
@@ -472,17 +514,20 @@ static void setup_for_type(GigoloBookmarkEditDialog *dialog)
 			gtk_table_attach(GTK_TABLE(table), priv->share_label,
 					  0, 1, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
 
-			gtk_label_set_mnemonic_widget(GTK_LABEL(priv->share_label), priv->share_entry);
-			gtk_widget_show(priv->share_entry);
-			gtk_table_attach(GTK_TABLE(table), priv->share_entry,
+			gtk_label_set_mnemonic_widget(GTK_LABEL(priv->share_label), priv->share_combo);
+			gtk_widget_show(priv->share_combo);
+			gtk_table_attach(GTK_TABLE(table), priv->share_combo,
 					  1, 2, i, i+1, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
 
+			gtk_widget_show(priv->share_button);
+			gtk_table_attach(GTK_TABLE(table), priv->share_button,
+					  2, 3, i, i+1, GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+
 			i++;
 		}
-
 	}
 
-	if (meth->flags)
+	if (meth->flags & (SHOW_PORT | SHOW_DOMAIN | SHOW_USER))
 	{
 		gtk_misc_set_alignment(GTK_MISC(priv->information_label), 0.0, 0.5);
 		gtk_widget_show(priv->information_label);
@@ -559,9 +604,9 @@ static void fill_method_combo_box(GigoloBookmarkEditDialog *dialog)
 	GigoloBookmarkEditDialogPrivate *priv = GIGOLO_BOOKMARK_EDIT_DIALOG_GET_PRIVATE(dialog);
 
 	/* 0 - method index, 1 - visible/supported flag, 2 - description */
-	store = gtk_list_store_new(3, G_TYPE_INT, G_TYPE_BOOLEAN, G_TYPE_STRING);
+	store = gtk_list_store_new(3, G_TYPE_UINT, G_TYPE_BOOLEAN, G_TYPE_STRING);
 
-	supported = g_vfs_get_supported_uri_schemes(g_vfs_get_default());
+	supported = gigolo_backend_gvfs_get_supported_uri_schemes();
 
 	for (i = 0; i < methods_len; i++)
 	{
@@ -589,8 +634,7 @@ static void fill_method_combo_box(GigoloBookmarkEditDialog *dialog)
 		}
 		scheme = gigolo_describe_scheme((methods[i].scheme != NULL) ? methods[i].scheme : "custom");
 
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter,
+		gtk_list_store_insert_with_values(store, &iter, -1,
 			COLUMN_INDEX, i,
 			COLUMN_VISIBLE, visible,
 			COLUMN_DESC, scheme,
@@ -639,11 +683,28 @@ static void update_bookmark(GigoloBookmarkEditDialog *dialog)
 	{
 		gigolo_bookmark_set_uri(priv->bookmark_update, gtk_entry_get_text(GTK_ENTRY(priv->uri_entry)));
 	}
+	else if (idx == SCHEME_OBEX)
+	{
+		gchar *host;
+
+		gigolo_bookmark_set_scheme(priv->bookmark_update, methods[idx].scheme);
+
+		tmp = gtk_entry_get_text(GTK_ENTRY(priv->host_entry));
+
+		if (tmp[0] != '[')
+			host = g_strconcat("[", tmp, "]", NULL);
+		else
+			host = (gchar *) tmp;
+
+		gigolo_bookmark_set_host(priv->bookmark_update, host);
+		if (tmp != host)
+			g_free(host);
+	}
 	else
 	{
 		gigolo_bookmark_set_scheme(priv->bookmark_update, methods[idx].scheme);
 
-		tmp = gtk_entry_get_text(GTK_ENTRY(priv->server_entry));
+		tmp = gtk_entry_get_text(GTK_ENTRY(priv->host_entry));
 		gigolo_bookmark_set_host(priv->bookmark_update, tmp);
 		tmp = gtk_entry_get_text(GTK_ENTRY(priv->user_entry));
 		gigolo_bookmark_set_user(priv->bookmark_update, tmp);
@@ -725,6 +786,45 @@ static void gigolo_bookmark_edit_dialog_set_property(GObject *object, guint prop
 }
 
 
+static void share_button_clicked_cb(GtkWidget *btn, GigoloBookmarkEditDialog *dialog)
+{
+	GigoloBookmarkEditDialogPrivate *priv = GIGOLO_BOOKMARK_EDIT_DIALOG_GET_PRIVATE(dialog);
+	const gchar *hostname;
+	gchar **shares;
+
+	gtk_list_store_clear(GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(priv->share_combo))));
+
+	hostname = gtk_entry_get_text(GTK_ENTRY(priv->host_entry));
+	if (! NZV(hostname))
+		return;
+
+	gtk_widget_set_sensitive(btn, FALSE);
+
+	/* FIXME for now we ignore username and domain when browsing for shares as this is not yet
+	 * supported by GVfs (1.0.x). */
+	shares = gigolo_backend_gvfs_get_smb_shares(hostname, NULL, NULL);
+
+	if (shares != NULL)
+	{
+		guint i, len = g_strv_length(shares);
+		for (i = 0; i < len; i++)
+		{
+			gtk_combo_box_append_text(GTK_COMBO_BOX(priv->share_combo), shares[i]);
+		}
+		g_strfreev(shares);
+	}
+	gtk_widget_set_sensitive(btn, TRUE);
+}
+
+
+static void host_entry_changed_cb(GtkEditable *editable, GtkWidget *btn)
+{
+	const gchar *text = gtk_entry_get_text(GTK_ENTRY(editable));
+
+	gtk_widget_set_sensitive(btn, NZV(text));
+}
+
+
 static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 {
 	GtkWidget *label;
@@ -753,7 +853,7 @@ static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 	hbox = gtk_hbox_new(FALSE, 6);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 
-	priv->table = table = gtk_table_new(9, 2, FALSE);
+	priv->table = table = gtk_table_new(9, 3, FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 6);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 12);
 	gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
@@ -794,16 +894,17 @@ static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 	g_signal_connect(combo, "changed", G_CALLBACK(combo_changed_callback), dialog);
 
 	priv->uri_entry = gtk_entry_new();
-	priv->server_entry = gtk_entry_new();
+	priv->host_entry = gtk_entry_new();
 	priv->port_spin = gtk_spin_button_new_with_range(0, 65535, 1);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->port_spin), 0.0);
 	gtk_widget_set_tooltip_text(priv->port_spin, _("Set the port to 0 to use the default port"));
 	priv->user_entry = gtk_entry_new();
 	priv->domain_entry = gtk_entry_new();
-	priv->share_entry = gtk_entry_new();
+	priv->share_combo = gtk_combo_box_entry_new_text();
+	priv->share_entry = gtk_bin_get_child(GTK_BIN(priv->share_combo));
 
 	priv->uri_label = gtk_label_new_with_mnemonic(_("_Location (URI):"));
-	priv->server_label = gtk_label_new_with_mnemonic(_("_Server:"));
+	priv->host_label = gtk_label_new_with_mnemonic(_("_Server:"));
 	priv->user_label = gtk_label_new_with_mnemonic(_("_User Name:"));
 	priv->information_label = gtk_label_new(_("Optional information:"));
 	priv->port_label = gtk_label_new_with_mnemonic(_("_Port:"));
@@ -812,22 +913,32 @@ static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 
 	gtk_entry_set_activates_default(GTK_ENTRY(priv->name_entry), TRUE);
 	gtk_entry_set_activates_default(GTK_ENTRY(priv->uri_entry), TRUE);
-	gtk_entry_set_activates_default(GTK_ENTRY(priv->server_entry), TRUE);
+	gtk_entry_set_activates_default(GTK_ENTRY(priv->host_entry), TRUE);
 	gtk_entry_set_activates_default(GTK_ENTRY(priv->port_spin), TRUE);
 	gtk_entry_set_activates_default(GTK_ENTRY(priv->user_entry), TRUE);
 
+	priv->share_button = gtk_button_new();
+	gtk_button_set_image(GTK_BUTTON(priv->share_button),
+		gtk_image_new_from_stock(GTK_STOCK_REFRESH, GTK_ICON_SIZE_MENU));
+	gtk_widget_set_sensitive(priv->share_button, FALSE);
+	g_signal_connect(priv->share_button, "clicked", G_CALLBACK(share_button_clicked_cb), dialog);
+
+	g_signal_connect(priv->host_entry, "changed",
+		G_CALLBACK(host_entry_changed_cb), priv->share_button);
+
 	/* We need an extra ref so we can remove them from the table */
 	g_object_ref(priv->uri_entry);
 	g_object_ref(priv->uri_label);
-	g_object_ref(priv->server_entry);
-	g_object_ref(priv->server_label);
+	g_object_ref(priv->host_entry);
+	g_object_ref(priv->host_label);
 	g_object_ref(priv->port_label);
 	g_object_ref(priv->port_spin);
 	g_object_ref(priv->user_entry);
 	g_object_ref(priv->user_label);
 	g_object_ref(priv->domain_entry);
 	g_object_ref(priv->domain_label);
-	g_object_ref(priv->share_entry);
+	g_object_ref(priv->share_combo);
+	g_object_ref(priv->share_button);
 	g_object_ref(priv->share_label);
 	g_object_ref(priv->information_label);
 
@@ -835,22 +946,21 @@ static void gigolo_bookmark_edit_dialog_init(GigoloBookmarkEditDialog *dialog)
 }
 
 
-GtkWidget *gigolo_bookmark_edit_dialog_new(GtkWindow *parent,
-		GigoloSettings *settings, GigoloBookmarkEditDialogMode mode)
+GtkWidget *gigolo_bookmark_edit_dialog_new(GigoloWindow *parent, GigoloBookmarkEditDialogMode mode)
 {
 	GigoloBookmarkEditDialog *dialog = g_object_new(GIGOLO_BOOKMARK_EDIT_DIALOG_TYPE,
 		"transient-for", parent,
 		"mode", mode,
 		NULL);
 	GigoloBookmarkEditDialogPrivate *priv = GIGOLO_BOOKMARK_EDIT_DIALOG_GET_PRIVATE(dialog);
-	priv->settings = settings;
+	priv->parent = parent;
 
 	return GTK_WIDGET(dialog);
 }
 
 
-GtkWidget *gigolo_bookmark_edit_dialog_new_with_bookmark(GtkWindow *parent,
-		GigoloSettings *settings, GigoloBookmarkEditDialogMode mode, GigoloBookmark *bookmark)
+GtkWidget *gigolo_bookmark_edit_dialog_new_with_bookmark(GigoloWindow *parent,
+		GigoloBookmarkEditDialogMode mode, GigoloBookmark *bookmark)
 {
 	GigoloBookmarkEditDialog *dialog = g_object_new(GIGOLO_BOOKMARK_EDIT_DIALOG_TYPE,
 		"transient-for", parent,
@@ -858,7 +968,7 @@ GtkWidget *gigolo_bookmark_edit_dialog_new_with_bookmark(GtkWindow *parent,
 		"mode", mode,
 		NULL);
 	GigoloBookmarkEditDialogPrivate *priv = GIGOLO_BOOKMARK_EDIT_DIALOG_GET_PRIVATE(dialog);
-	priv->settings = settings;
+	priv->parent = parent;
 
 	return GTK_WIDGET(dialog);
 }
