@@ -27,6 +27,7 @@
 #include "common.h"
 #include "compat.h"
 #include "settings.h"
+#include "backendgvfs.h"
 #include "preferencesdialog.h"
 
 
@@ -98,6 +99,14 @@ static void check_button_toggle_cb(GtkToggleButton *button, GigoloSettings *sett
 }
 
 
+static void check_button_toggle_sensitive_cb(GtkToggleButton *button, GtkWidget *widget)
+{
+    gboolean toggled = gtk_toggle_button_get_active(button);
+
+	gtk_widget_set_sensitive(widget, toggled);
+}
+
+
 static void check_toolbar_show_toggle_cb(GtkToggleButton *button, G_GNUC_UNUSED gpointer data)
 {
     gboolean toggled = gtk_toggle_button_get_active(button);
@@ -183,7 +192,7 @@ static GtkWidget *add_view_mode_combo(GigoloSettings *settings, const gchar *pro
 
 	widget = gtk_combo_box_new_text();
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Symbols"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Detailed"));
+	gtk_combo_box_append_text(GTK_COMBO_BOX(widget), _("Detailed List"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget), value);
 
@@ -301,7 +310,7 @@ static GtkWidget *add_spinbutton(GigoloSettings *settings, const gchar *property
 static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settings)
 {
 	GtkWidget *frame_vbox, *notebook_vbox, *vbox, *hbox, *notebook;
-	GtkWidget *radio1, *radio2, *checkbox, *combo, *entry, *combo_toolbar_style;
+	GtkWidget *radio1, *radio2, *checkbox, *combo, *entry, *combo_toolbar_style, *tmp_box;
 	GtkWidget *combo_toolbar_orient, *spinbutton;
 	GtkWidget *label1, *label2, *label3, *label4, *label_volman, *image;
 	GSList *rlist;
@@ -397,16 +406,27 @@ static void set_settings(GigoloPreferencesDialog *dialog, GigoloSettings *settin
 	gtk_widget_set_tooltip_text(checkbox, _("Saves the window position and geometry and restores it at the start"));
 	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
 
-	checkbox = add_check_button(settings, "show-in-systray", _("Show status _icon in the Notification Area"));
+	tmp_box = checkbox = add_check_button(settings, "show-in-systray", _("Show status _icon in the Notification Area"));
 	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
 
 	checkbox = add_check_button(settings, "start-in-systray", _("Start _minimized in the Notification Area"));
 	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+	g_signal_connect(tmp_box, "toggled", G_CALLBACK(check_button_toggle_sensitive_cb), checkbox);
+	check_button_toggle_sensitive_cb(GTK_TOGGLE_BUTTON(tmp_box), checkbox);
+
+	checkbox = add_check_button(settings, "show-panel", _("Show 'Browse Network' side panel"));
+	gtk_widget_set_tooltip_text(checkbox, _("Whether to show a side panel for browsing the local network for available Samba shares"));
+	gtk_widget_set_sensitive(checkbox, gigolo_backend_gvfs_is_scheme_supported("smb"));
+	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
+
+	checkbox = add_check_button(settings, "show-autoconnect-errors", _("Show auto-connect error messages"));
+	gtk_widget_set_tooltip_text(checkbox, _("Whether to show error message dialogs when auto-connecting of bookmarks fails"));
+	gtk_box_pack_start(GTK_BOX(frame_vbox), checkbox, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new(FALSE, 6);
 	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
 
-	label4 = gtk_label_new_with_mnemonic(_("_View Mode"));
+	label4 = gtk_label_new_with_mnemonic(_("_Connection List Mode"));
 	gtk_misc_set_alignment(GTK_MISC(label4), 0.0f, 0.5f);
 	gtk_box_pack_start(GTK_BOX(hbox), label4, FALSE, FALSE, 0);
 
@@ -516,7 +536,6 @@ GtkWidget *gigolo_preferences_dialog_new(GtkWindow *parent, GigoloSettings *sett
 		"settings", settings,
 		NULL);
 
-
 	return dialog;
 }
 
